% code related to the paper "Stable and Efficient Gaussian Process
%    Calculations" by L. Foster, et. al., accepted for publication in the 
%    Journal of Machine Learning Research
% This code implements in a numerically stable manner Gaussian process
%    regression using low rank approximation
% date: 2009-01-13.
%
% demo_bootstrap.m  - demonstration program comparing the numerical
%                     stability of various algorithms for Gaussian
%                     process regression algorithms using low rank
%                     approximation and illustrating bootstrap resampling
% demo_history.m -    demonstration program illustrating a feature  
%                     that allows efficient calculation of the accuracy
%                     of all low rank approximations less than or equal to
%                     a specified rank 
%
% Running these demonstrations is an excellent introduction to the code
%
% chol_part.m -       partial Cholesky factorization
% contents.m -        this file
% covNNone.m -        neural network covariance function, this is a 
%                     modification that reduces memory use of the
%                     covNNone.m function available at
%                     www.gaussianprocess.org/gpml/code/matlab/doc/
% gprSRPPn.m -        implementation of the subset of regressors method
%                     using the normal equations approach
% gprSRPPnp.m -       implementation of the subset of regressors method
%                     using the normal equations approach with the active
%                     set chosen by partial Cholesky factorization with
%                     pivoting
% gprSRPPv.m -        implementation of the subset of regressors method
%                     using the V method
% gprSRPPvp.m -       implementation of the subset of regressors method
%                     using the V method with the active set chosen by
%                     partial Cholesky factorization with pivoting
% gprSRPPq.m -        implementation of the subset of regressors method
%                     using a QR factorization
% gprSRPPqp.m -       implementation of the subset of regressors method
%                     using a QR factorization with the active set chosen
%                     by partial Cholesky factorization with pivoting
% redshift_data.mat - a Matlab mat file that contains data for galaxy redshift
%                     approximation.  The data comes from the Sloan Digital
%                     Sky Survey ( http://www.sdss.org/ ).
%
% copyrights.txt -    Copyright information for the above code and the code
%                     from Rasmussen and Williams.  Also acknowledgement for
%                     use of the Sloan Digital Sky Survey data.
%
% The following are routines copied unchanged from Rasmussen and Williams code
% at www.gaussianprocess.org/gpml/code/matlab/doc/.  They are included so that 
% the demonstration files can run using only code provided in this set of 
% routines.
%
% covNoise.m -        independent covariance function (ie white noise)
% covSum.m -          function for adding other covariance functions
% gpr.m -             Gaussian process regression with general covariance
% gprSRPP.m -         Implements SR and PP approximations to GPR
% minimize.m -        Minimize a differentiable multivariate function
% solve_chol.m -      Solve linear equations from the Cholesky factorization
%                     (a Matlab implementation that may not be efficient)





